@@ -11,7 +11,7 @@ use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Get XML.
 has xml => (
@@ -37,9 +37,9 @@ Map::Tube::KualaLumpur - Interface to the KualaLumpur urban monorail system map.
 
  use Map::Tube::KualaLumpur;
  my $obj = Map::Tube::KualaLumpur->new;
- my $route = $obj->get_shortest_route($from, $to);
- my $xml_file = $obj->xml;
  my $routes_ar = $obj->get_all_routes($from, $to);
+ my $line = $obj->get_line_by_id($line_id);
+ my $line = $obj->get_line_by_name($line_name);
  my $lines_ar = $obj->get_lines;
  my $station = $obj->get_node_by_id($station_id);
  my $station = $obj->get_node_by_name($station_name);
@@ -68,6 +68,16 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
  Get all routes from station to station.
  Returns reference to array with Map::Tube::Route objects.
 
+=item C<get_line_by_id($line_id)>
+
+ Get line object defined by id.
+ Returns Map::Tube::Line object.
+
+=item C<get_line_by_name($line_name)>
+
+ Get line object defined by name.
+ Returns Map::Tube::Line object.
+
 =item C<get_lines()>
 
  Get lines in metro map.
@@ -83,16 +93,6 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
  Get station node by name.
  Returns Map::Tube::Node object.
 
-=item C<get_line_by_id($line_id)>
-
- Get line by id.
- Returns Map::Tube::Line object.
-
-=item C<get_line_by_name($line_name)>
-
- Get line by name.
- Returns Map::Tube::Line object.
-
 =item C<get_shortest_route($from, $to)>
 
  Get shortest route between $from and $to node names. Node names in $from and $to are case insensitive.
@@ -158,6 +158,72 @@ For more information about KualaLumpur Map, click L<here|https://https://en.wiki
  # Output like:
  # XML file: .*/kuala_lumpur-map.xml
 
+=head1 EXAMPLE3
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Map::Tube::GraphViz;
+ use Map::Tube::GraphViz::Utils qw(node_color_without_label);
+ use Map::Tube::KualaLumpur;
+
+ # Object.
+ my $obj = Map::Tube::KualaLumpur->new;
+
+ # GraphViz object.
+ my $g = Map::Tube::GraphViz->new(
+         'callback_node' => \&node_color_without_label,
+         'tube' => $obj,
+ );
+
+ # Get graph to file.
+ $g->graph('KualaLumpur.png');
+
+ # Print file.
+ system "ls -l KualaLumpur.png";
+
+ # Output like:
+ # -rw-r--r-- 1 skim skim 379962 Sep 28 12:11 KualaLumpur.png
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-KualaLumpur/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-KualaLumpur/master/images/ex3.png" alt="Rapid Rail" width="300px" height="300px" />
+</a>
+
+=end html
+
+=head1 EXAMPLE4
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Encode qw(encode_utf8);
+ use Map::Tube::KualaLumpur;
+
+ # Object.
+ my $obj = Map::Tube::KualaLumpur->new;
+
+ # Get lines.
+ my $lines_ar = $obj->get_lines;
+
+ # Print out.
+ map { print encode_utf8($_->name)."\n"; } sort @{$lines_ar};
+
+ # Output:
+ # Ampang Line
+ # KL Monorail Line
+ # KLIA Ekspres Line
+ # KLIA Transit Line
+ # Kelana Jaya Line
+ # Port Klang Line
+ # Seremban Line
+ # Sri Petaling Line
+
 =head1 DEPENDENCIES
 
 L<File::Share>,
@@ -167,9 +233,21 @@ L<namespace::clean>.
 
 =head1 SEE ALSO
 
-L<Map::Tube>,
-L<Task::Map::Tube>,
-L<Task::Map::Tube::Metro>.
+=over
+
+=item L<Map::Tube>
+
+Core library as Role (Moo) to process map data.
+
+=item L<Task::Map::Tube>
+
+Install the Map::Tube modules.
+
+=item L<Task::Map::Tube::Metro>
+
+Install the Map::Tube concrete metro modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -189,6 +267,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
